The AEA framework has two commercial roles which are outlined below.


## Open source technology

We are creating infrastructure for developers to build their own agent-based solutions. 

AEA users are, among others:

* Data scientists.
* Economists.
* Researchers (Artificial Intelligence, Machine Learning, Multi-Agent Systems).
* Engineers.
* Machine learning experts.
* Independent developers.
* Students and academics.
* Crypto connoisseurs and enthusiasts.
* Web developers.


## Platform for start ups

By operating as a platform for start ups, we envisage the AEA framework to be in a continuous growth pattern.

With start up grants we will kick start solutions while testing product-problem fit and identifying our user base.



<br />

